@@ -188,11 +188,11 @@ class CreateDBInstanceHourRequest(AbstractModel):
         :type ProjectId: int
         :param Tags: Instance tag information
         :type Tags: list of TagInfo
-        :param Clone: 
+        :param Clone: Valid values: 1 (regular instance), 2 (temp instance), 3 (read-only instance), 4 (disaster recovery instance).
         :type Clone: int
-        :param Father: 
+        :param Father: Parent instance ID. It is required if the `Clone` is 3 or 4.
         :type Father: str
-        :param SecurityGroup: 
+        :param SecurityGroup: Security group.
         :type SecurityGroup: list of str
         """
         self.Memory = None
@@ -277,7 +277,7 @@ class CreateDBInstanceRequest(AbstractModel):
         :type Memory: int
         :param Volume: Instance disk size in GB.
         :type Volume: int
-        :param MongoVersion: Version number. For the specific purchasable versions supported, please see the return result of the `DescribeSpecInfo` API. The correspondences between parameters and versions are as follows: MONGO_3_WT: MongoDB 3.2 WiredTiger Edition; MONGO_3_ROCKS: MongoDB 3.2 RocksDB Edition; MONGO_36_WT: MongoDB 3.6 WiredTiger Edition.
+        :param MongoVersion: Version number. For the specific purchasable versions supported, please see the return result of the `DescribeSpecInfo` API. The correspondences between parameters and versions are as follows: MONGO_3_WT: MongoDB 3.2 WiredTiger Edition; MONGO_3_ROCKS: MongoDB 3.2 RocksDB Edition; MONGO_36_WT: MongoDB 3.6 WiredTiger Edition; MONGO_40_WT: MongoDB 4.0 WiredTiger Edition.
         :type MongoVersion: str
         :param GoodsNum: Number of instances. Minimum value: 1. Maximum value: 10.
         :type GoodsNum: int
@@ -285,11 +285,11 @@ class CreateDBInstanceRequest(AbstractModel):
         :type Zone: str
         :param Period: Instance validity period in months. Valid values: 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 24, 36.
         :type Period: int
-        :param MachineCode: Server type. Valid values: HIO (high IO), HIO10G (10-gigabit high IO).
+        :param MachineCode: Server type. Valid values: HIO (high IO), HIO10G (10-gigabit high IO), STDS5 (standard).
         :type MachineCode: str
-        :param ClusterType: Instance type. Valid values: REPLSET (replica set), SHARD (sharded cluster).
+        :param ClusterType: Instance type. Valid values: REPLSET (replica set), SHARD (sharded cluster), STANDALONE (single-node).
         :type ClusterType: str
-        :param ReplicateSetNum: Number of replica sets. To create a replica set instance, set this parameter to 1; to create a shard instance, see the parameters returned by the `DescribeSpecInfo` API.
+        :param ReplicateSetNum: Number of replica sets. To create a replica set instance, set this parameter to 1; to create a shard instance, see the parameters returned by the `DescribeSpecInfo` API; to create a single-node instance, set this parameter to 0.
         :type ReplicateSetNum: int
         :param ProjectId: Project ID. If this parameter is not set, the default project will be used.
         :type ProjectId: int
@@ -303,13 +303,13 @@ class CreateDBInstanceRequest(AbstractModel):
         :type Tags: list of TagInfo
         :param AutoRenewFlag: Auto-renewal flag. Valid values: 0 (auto-renewal not enabled), 1 (auto-renewal enabled). Default value: 0.
         :type AutoRenewFlag: int
-        :param AutoVoucher: 
+        :param AutoVoucher: Whether to automatically use a voucher. Valid values: 1 (yes), 0 (no). Default value: 0.
         :type AutoVoucher: int
-        :param Clone: 
+        :param Clone: Valid values: 1 (regular instance), 2 (temp instance), 3 (read-only instance), 4 (disaster recovery instance).
         :type Clone: int
-        :param Father: 
+        :param Father: Primary instance ID. It is required for read-only and disaster recovery instances.
         :type Father: str
-        :param SecurityGroup: 
+        :param SecurityGroup: Security group.
         :type SecurityGroup: list of str
         """
         self.NodeNum = None
